#include <stdio.h>
#include <stdlib.h>
#include <usb.h>

#define FALSE   0
#define TRUE    1

#define SET_DISPLAY_POT     0x01
#define GET_POT_VALUE       0x02
#define GET_ALL_POTS        0x03

int main(int argc, char *argv[]) {
    struct usb_bus *bus;
    struct usb_device *dev;
    usb_dev_handle *udev;
    int dev_found, ret, pot;
    char string[256];
    unsigned char buffer[8];
    
    if (argc != 2) {
        printf("Usage: %s <pot_number>\n", argv[0]);
        exit(-1);
    }
    pot = atoi(argv[1]);
    if ((pot < 0) || (pot > 5)) {
        printf("Illegal potentiometer number (%d) specified.\n", pot);
        exit(-1);
    }

    usb_init();

    usb_find_busses();
    usb_find_devices();

    udev = NULL;
    dev_found = FALSE;
    for (bus = usb_get_busses(); bus && !dev_found; bus = bus->next) {
        for (dev = bus->devices; dev && !dev_found; dev = dev->next) {
            if ((dev->descriptor.idVendor == 0x04D8) && (dev->descriptor.idProduct == 0x0003)) {
                dev_found = TRUE;
                udev = usb_open(dev);
            }
        }
    }
    if (!dev_found) {
        printf("No matching device found...\n");
    }
    if (udev) {
        ret = usb_control_msg(udev, 0xC0, GET_POT_VALUE, 0, pot, buffer, 1, 100);
        if (ret < 0) {
            printf("Unable to send vendor request, ret = %d...\n", ret);
        }
        printf("Potentiometer %d value is 0x%X.\n", pot, buffer[0]);
        usb_close(udev);
    }
}
